udbgutil.o udbgutil.d : ../../../icu/source/tools/toolutil/udbgutil.cpp \
 ../../../icu/source/tools/toolutil/udbgutil.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/ustr_imp.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/i18n/unicode/ulocdata.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/unicode/uloc.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/cstr.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/charstr.h \
 ../../../icu/source/i18n/unicode/ucal.h \
 ../../../icu/source/i18n/unicode/udat.h \
 ../../../icu/source/i18n/unicode/unum.h \
 ../../../icu/source/common/unicode/ucurr.h \
 ../../../icu/source/common/unicode/umisc.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/i18n/unicode/uformattable.h \
 ../../../icu/source/common/unicode/udisplaycontext.h \
 ../../../icu/source/i18n/unicode/ufieldpositer.h \
 ../../../icu/source/i18n/unicode/ucol.h \
 ../../../icu/source/common/unicode/unorm.h \
 ../../../icu/source/common/unicode/uiter.h \
 ../../../icu/source/common/unicode/unorm2.h \
 ../../../icu/source/common/unicode/uscript.h
