package.o package.d : ../../../icu/source/tools/toolutil/package.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/uarrsort.h \
 ../../../icu/source/common/ucmndata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/umapfile.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/tools/toolutil/swapimpl.h \
 ../../../icu/source/tools/toolutil/toolutil.h \
 ../../../icu/source/common/unicode/errorcode.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/tools/toolutil/package.h \
 ../../../icu/source/common/cmemory.h
